==> nextcloud-29.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Верзија {version} је доступна. Сазнајте како да ажурирате.",
    "Channel updated" : "Канал ажуриран",
    "Web updater is disabled" : "Веб алат за ажурирање је искључен",
    "App updated" : "Апликација је ажурирана",
    "See what's new" : "Погледајте шта има ново",
    "{app} updated to version {version}" : "{app} је ажурирана на верзију {version}",
    "Update notifications" : "Обавештења о ажурирању",
    "The update server could not be reached since %d days to check for new updates." : "Сервер за ажурирања није доступан пошто је прошло %d дана од последње провере ажурирања.",
    "Please check the Nextcloud and server log files for errors." : "Проверите логове од сервера и од Некстклауда за грешке.",
    "Update to {serverAndVersion} is available." : "Доступно је ажурирање на {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Доступно је ажурирање апликације {app} на верзију %s.",
    "Update notification" : "Обавештење о ажурирању",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Приказује обавештавања о ажурирањима за Nextcloud, апликације и омогућава јединствену пријаву за програм ажурирања.",
    "What's new in {app} {version}" : "Шта има ново у {app} {version}",
    "Give feedback" : "Пошањите повратне информације",
    "Get started" : "Хајде да почнемо",
    "No changelog available" : "Није доступан дневник измена",
    "Update" : "Ажурирај",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзија коју тренутно користите се више не одржава. Постарајте се да ажурирате инсталацију на неку подржану верзију што је пре могуће.",
    "Apps missing compatible version" : "Апликације које немају компатибилну верзију",
    "View in store" : "Погледај у продавници",
    "Apps with compatible version" : "Апликације са компатибилном верзијом",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Молимо вас да имате на уму да се веб алат за ажурирање не препоручује када постоји више од 100 налога! Молимо вас да у том случају употребите ажурирање из командне линије!",
    "Open updater" : "Отвори програм за ажурирање",
    "Download now" : "Скини сада",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Веб алат за ажурирање је искључен. Молимо вас да употребите алат за ажурирање из командне линије или механизам који одговара начину на који сте инсталирали Nextcloud (нпр. Docker повлачење).",
    "What's new?" : "Шта је ново?",
    "View changelog" : "Погледајте дневник измена",
    "The update check is not yet finished. Please refresh the page." : "Провера за новим верзијама још није готова. Освежите страну.",
    "Your version is up to date." : "Ваша верзија је ажурна.",
    "A non-default update server is in use to be checked for updates:" : "Неподразумевани сервер за ажурирање је коришћен да провери нове верзије:",
    "Update channel" : "Канал ажурирања",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Промена канала ажурирања такође утиче и на страницу за управљање апликацијама. Нпр. када се пребаците на бета канал, на страници за управљање апликацијама ће вам се нудити и бета ажурирања апликација.",
    "Current update channel:" : "Тренутни канал ажурирања:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Увек можете да надоградите на новију верзију. Али не можете се вратити на стабилнију верзију.",
    "Notify members of the following groups about available updates:" : "Обавести чланове следећих група о доступности нових верзија:",
    "No groups" : "Нема група",
    "Only notifications for app updates are available." : "Доступна су само обавештења о ажурирањима апликација.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Уз означени канал за ажурирање нема смисла да имате обавештења о новим верзијама.",
    "The selected update channel does not support updates of the server." : "Означени канал за ажурирање не подржава обавештења о новим верзијама.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна је нова верзија: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Имајте на уму да се након новог издања ажурирање појављује само након првог малог издања или касније. Нове верзије издајемо у временском размаку, а понекад и прескочимо верзију онда када се открију проблеми. Сазнајте више о ажурирањима и каналима издања на {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Проверено {lastCheckedDate} - Отвори дневник измена",
    "Checking apps for compatible versions" : "Проверава се постојање компатибилних верзија апликација",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Проверите да у config.php фајлу немате <samp>appstoreenabled</samp> постављено на „false“.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Није успело повезивање са Продавницом апликација или није враћено ниједно ажурирање. Потражите ручно ажурирања или обезбедите да ваш сервер има приступ интернету и да има могучност успостављања везе са Продавницом апликација.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Све</strong> апликације имају верзију која је компатибилна са  верзијом ове Nextcloud инстанце.",
    "Enterprise" : "Предузетничка",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За предузећа. Пружа најновији ниво закрпа, али неће одмах да ажурира аутоматски на следећу главну верзију. То ажурирање ће се десити када Nextcloud GmbH обави додатне провере и тестирања на великим и критичним системима. Овај канал је доступан само муштеријама и пружа  Nextcloud Enterprise пакет.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најскорашњија стабилна верзија. Погодна за редовну употребу и увек ће бити на најновијој главној верзији.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Пред-издање и служи само за тестирање нових могућности, не за свакодневни рад.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове Nextcloud инстанце.","<strong>%n</strong> апликација немају верзију која је компатибилна са верзијом ове Nextcloud инстанце.","<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове Nextcloud инстанце."],
    "Changelog for app {app}" : "Дневник измена апликације {app}",
    "What's new in {app} version {version}" : "Шта има ново у {app} верзије {version}",
    "Update to %1$s is available." : "Доступно је ажурирање на %1$s. ",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Приказује обавештавања о ажурирањима за Некстклауд и омогућава јединствену пријаву за програм ажурирања.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Молимо вас да имате на уму да се веб алат за ажурирање не препоручује када постоји више од 100 корисника! Молимо вас да у том случају употребите ажурирање из командне линије!",
    "Please use the command line updater to update." : "Молимо вас да за ажурирање употребите алат из командне линије.",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Имајте на уму да се након новог издања ажурирање појављује само након првог малог издања или касније. Нове верзије издајемо својим корисницима у временском размаку, а понекад и прескочимо верзију онда када се открију проблеми. Сазнајте више о ажурирањима и каналима издања на {link}"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Канал ажуриран",
    "Web updater is disabled" : "Веб алат за ажурирање је искључен",
    "Configuration is read-only" : "Конфигурација може само да се чита",
    "App updated" : "Апликација је ажурирана",
    "See what's new" : "Погледајте шта има ново",
    "{app} updated to version {version}" : "{app} је ажурирана на верзију {version}",
    "Update notifications" : "Обавештења о ажурирању",
    "The update server could not be reached since %d days to check for new updates." : "Сервер за ажурирања није доступан пошто је прошло %d дана од последње провере ажурирања.",
    "Please check the Nextcloud and server log files for errors." : "Проверите логове од сервера и од Некстклауда за грешке.",
    "Update to {serverAndVersion} is available." : "Доступно је ажурирање на {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Доступно је ажурирање апликације {app} на верзију %s.",
    "Update notification" : "Обавештење о ажурирању",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Приказује обавештавања о ажурирањима за Nextcloud, апликације и омогућава јединствену пријаву за програм ажурирања.",
    "Give feedback" : "Пошаљите повратне информације",
    "Get started" : "Хајде да почнемо",
    "No changelog available" : "Није доступан дневник измена",
    "What's new in {app} {version}" : "Шта има ново у {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна је нова верзија: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Имајте на уму да се након новог издања ажурирање појављује само након првог малог издања или касније. Нове верзије издајемо у временском размаку, а понекад и прескочимо верзију онда када се открију проблеми. Сазнајте више о ажурирањима и каналима издања на {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Проверено {lastCheckedDate} - Отвори дневник измена",
    "Checking apps for compatible versions" : "Проверава се постојање компатибилних верзија апликација",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Проверите да у config.php фајлу немате <samp>appstoreenabled</samp> постављено на „false“.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Није успело повезивање са Продавницом апликација или није враћено ниједно ажурирање. Потражите ручно ажурирања или обезбедите да ваш сервер има приступ интернету и да има могучност успостављања везе са Продавницом апликација.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Све</strong> апликације имају верзију која је компатибилна са  верзијом ове {productName} инстанце.",
    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове {productName} инстанце.","<strong>%n</strong> апликације немају верзију која је компатибилна са верзијом ове {productName} инстанце.","<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове {productName} инстанце."],
    "Enterprise" : "Предузетничка",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "За употребу у предузећима. Увек обезбеђује последњи ниво закрпе, али се неће одмах ажурирати на наредно главно издање.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "Ажурирање се врши онда када {vendor} уради додатно ојачање и тестирање за велике инсталације као оне које су критичне за пословање.",
    "This channel is only available to customers and provides the {enterprise} package." : "Овај канал је доступан само купцима и обезбеђује {enterprise} пакет.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најскорашњија стабилна верзија. Погодна за редовну употребу и увек ће бити на најновијој главној верзији.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Пред-издање и служи само за тестирање нових могућности, не за свакодневни рад.",
    "Update" : "Ажурирај",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзија коју тренутно користите се више не одржава. Постарајте се да ажурирате инсталацију на неку подржану верзију што је пре могуће.",
    "Apps missing compatible version" : "Апликације које немају компатибилну верзију",
    "View in store" : "Погледај у продавници",
    "Apps with compatible version" : "Апликације са компатибилном верзијом",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Молимо вас да имате на уму да се веб алат за ажурирање не препоручује када постоји више од 100 налога! Молимо вас да у том случају употребите ажурирање из командне линије!",
    "Open updater" : "Отвори програм за ажурирање",
    "Download now" : "Скини сада",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Веб алат за ажурирање је искључен. Молимо вас да употребите алат за ажурирање из командне линије или механизам који одговара начину на који сте инсталирали Nextcloud (нпр. Docker повлачење).",
    "What's new?" : "Шта је ново?",
    "View changelog" : "Погледајте дневник измена",
    "The update check is not yet finished. Please refresh the page." : "Провера за новим верзијама још није готова. Освежите страну.",
    "Your version is up to date." : "Ваша верзија је ажурна.",
    "A non-default update server is in use to be checked for updates:" : "Неподразумевани сервер за ажурирање је коришћен да провери нове верзије:",
    "Update channel" : "Канал ажурирања",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Промена канала ажурирања такође утиче и на страницу за управљање апликацијама. Нпр. када се пребаците на бета канал, на страници за управљање апликацијама ће вам се нудити и бета ажурирања апликација.",
    "Current update channel:" : "Тренутни канал ажурирања:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Увек можете да надоградите на новију верзију. Али не можете се вратити на стабилнију верзију.",
    "Notify members of the following groups about available updates:" : "Обавести чланове следећих група о доступности нових верзија:",
    "No groups" : "Нема група",
    "Only notifications for app updates are available." : "Доступна су само обавештења о ажурирањима апликација.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Уз означени канал за ажурирање нема смисла да имате обавештења о новим верзијама.",
    "The selected update channel does not support updates of the server." : "Означени канал за ажурирање не подржава обавештења о новим верзијама.",
    "Changelog for app {app}" : "Дневник измена апликације {app}",
    "What's new in {app} version {version}" : "Шта има ново у {app} верзије {version}",
    "{version} is available. Get more information on how to update." : "Верзија {version} је доступна. Сазнајте како да ажурирате.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Све</strong> апликације имају верзију која је компатибилна са  верзијом ове Nextcloud инстанце.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове Nextcloud инстанце.","<strong>%n</strong> апликација немају верзију која је компатибилна са верзијом ове Nextcloud инстанце.","<strong>%n</strong> апликација нема верзију која је компатибилна са верзијом ове Nextcloud инстанце."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За предузећа. Пружа најновији ниво закрпа, али неће одмах да ажурира аутоматски на следећу главну верзију. То ажурирање ће се десити када Nextcloud GmbH обави додатне провере и тестирања на великим и критичним системима. Овај канал је доступан само муштеријама и пружа  Nextcloud Enterprise пакет."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
